Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

16x01 - Road to the Runway

Episode transcripts for the TV show, "Project Runway". Aired: December 1, 2004 – present.*
Watch/Buy Amazon


Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.

16x01 - Road to the Runway

Post by bunniefuu »

♪ ♪

Welcome to New York City,
and to Project Runway season 16.

This is the Road to the Runway.

We're about to reveal exactly
what the designers go through

to make it here,
to this very stage.

It takes talent and tenacity

to secure a coveted spot
on Project Runway,

but what you may not realize

is that the journey to get here
is almost as challenging

as making it
to New York Fashion Week.

The selection process begins

with a nationwide casting call

where thousands
of aspiring fashion designers

submit their portfolios
and home videos.

My design philosophy

is mixing genders,
mixing sexuality.

MARGARITA:
The woman that I design for,

she's my mom, my sister,
she's me.

This is my audition video.

TIM: From there,
the most promising designers

are invited to audition
before a panel of judges.

MILA: I can't stop looking
at what you have on.

As designers anxiously wait

for their name to be called,

the room is filled
with a mix of excitement

-and nervous energy.
-PRODUCER: And at the end

you'll get a yes,
a no or a maybe

from each
of the three panelists.

Several nail-biting weeks pass

before 16 lucky finalists
get the call.

They made the show.

[laughing]:
Yeah!

Really?

I look forward to the privilege
of mentoring this talented group

in the workroom this season.

Tim Gunn, like,
do I have to say more?

Like, I'm coming for Tim,
like... [laughs]

So, let's begin.

I am proud to introduce you

to the fresh and fabulous faces

of our sweet 16 season.

-[dog yipping]
-Hi, Project Runway.

[continues yipping]

First up,
four fierce fashionistas

who are primed
to leave the competition

in the dust.

♪ ♪

MILA: She's from right here
in Inglewood.

-ALLISON: Self-taught.
-MILA: Interesting.

BATANI: I'm Batani-Khalfani.
I'm 32 years old

and I'm from Los Angeles,
California.

-You are gorgeous. -I know,
look how gorgeous you look.

ANTHONY: Can we see the back
of what you've got on?

-I know, give us a twirl.
-Look.

-[soft laughter]
-MILA: That's fabulous.

BATANI: My personal style
is kind of funky, kind of edgy,

and then it's also kind
of sexy. I like to wear

different colors,
different prints.

I'm really into African prints,

as you can see.
Let me show you this top

and this skirt. It's a set.

PRODUCER:
Do you put anything under that?

[whispers]: Actually, I don't.
[laughs]

I've been playing
with a lot of ankara prints

This goes kind of
off the shoulder,

-ANTHONY: Uh-huh.
-And it's fitted on the waist.

Here's a little jacket,
a blazer.

And this dress
has a split in the front--

-you can't really see it-- can
you see it? -ANTHONY: Mm-hmm.

♪ ♪

So I grew up on the east side

of Los Angeles.

Grimy, gangs.

My parents, very protective.

When I was in high school,

I used to get picked up
by my dad.

I couldn't walk home.

I had that upbringing
to be proud of who I am.

I never had to question
who I was.

I'm most excited
by what you're wearing.

-MILA: Me too.
-You're your own best model.

I agree. I'm... I can't stop
looking at what you have on.

-Yeah. -And even the styling
with the earrings

and the boots and the bracelet,
I love it.

BATANI: People tell me
that I inspire them.

I feel like, in order to live,

you have to live free.

You can't just exist
in this world.

It's like you're coming upon

the edge of a cliff,

and you don't know
what's down there,

like, you can't see anything.

So what are you gonna do?
I always jump.

I have wings, so I'm gonna fly.

And I'm not ever gonna fall.

I give you a yes.
I like you,

I can see your brand.

I can see the girl.

I like what you're doing
with prints,

so keep it up.

-Thank you all.
-MILA: Thank you.

BATANI:
Have a good day.

MILA:
Thank you, you too.

I know, it's so funny,
with all those prints...

-But she can wear it, it's not
wearing her. -ANTHONY: Mm-hmm.

-Totally. -Some people, they can
walk in... -She had me at hello.

-Hmm. She's never tried out
before. -MILA: It's funny...

-ANTHONY: I think she teaches.
-PRODUCER: Amy Bond?

ALLISON:
Where are we?

Hi, I'm Amy Bond.

-JUDGES: Hi, Amy.
-Hi.

First time trying out?

-Uh, yes, it is. Yes...
-And you teach?

I do. I'm an associate professor

at Otis College
of Art and Design.

I've been in fashion
my whole life.

I spend most
of my time draping,

so I don't sketch so much.

I start three dimensional,

and then I'll drape.

I take photos of that drape,

I'll print those out
in different sizes,

use that as a reference
and kind of go from there.

So that's been my process that's
kind of gotten me to this point.

So in this pant,

for instance, which is fabulous,
because it is also

lined in silk charmeuse,

-so it feels like a dream.
-Oh, nice. Yeah.

So it slides on, and then
the belt just wraps-- oh, sorry.

[laughter]

♪ ♪

We're in Downtown Los Angeles.

Welcome to my home.

Let's meet the family.

This is my spouse, Angelo.

This is my daughter Delilah.

These guys are the backbone
of everything.

I wouldn't have the creative
freedom or the energy

or the free spirit to do
any kind of design work

if it weren't for their love
and support.

[laughter]

AMY: If the contestants are--
some of them or a lot of them--

were younger,
or that much younger than me,

like in the early 20s,
I know what I would

have on them
is my years of experience.

I love teaching,
I love the kids.

It's been really,
really rewarding.

So why have you come today?

Come to that point
where it's like,

"Hey, my turn."

-Right.
-Can we see the rest?

-I'm so curious.
-Yeah.

AMY:
So...

A-line dress version,
so my challenge

was how to put a closure in it,

-since I did no side seams...
-Okay. -Okay.

-No center back seam.
-ANTHONY: Okay.

So my solution
was the invisible zipper.

I bet you'd nail

a red carpet challenge.

I got an hour, wha...

[laughter]

For me, it's an easy yes.
I like you, I like your style.

I would agree. I think you have
a real strength.

-MILA: Congratulations.
-ANTHONY: Congratulations.

-Yay. Thank you.
-MILA: Thank you.

-Guess I'll roll out.
-ALLISON: Thank you.

I want those pants.

[laughter]

AYANA: Hi, everybody,
my name is Ayana Ife.

I design modest fashion
for religious purposes.

or for just, like,
fashion preferences.

Well, take us through
a little of it.

AYANA: Well, this one
is a boyfriend shirt.

I kind of put
my own spin on it,

where I did, like, a
sideways collar and then, like,

a sideways closure.

AYANA:
Welcome to my castle.

-[meows]
-This is how it all starts.

From my mind to a rough sketch.

Once I know
exactly how I want it,

I can actually make it.

AYANA: This dress right here
is a special occasion piece,

-Mm-hmm. -And then,
this one is more of, like,

a sexy-type modest-- so if you
want to turn from the back--

it can be worn with, like,
a bandeau or something.

I like the...

religious influence that's here.

My one concern is fabric choice.

-Okay.
-Okay?

If I'm being blatantly honest...

it looks like
you have pantyhose on your head.

-[laughs]
-Okay?

-It's the power mesh that...
-It is power mesh.

AYANA: The covering is just kind
of, like, saying,

you know, I am Muslim.

You know, you can see me coming
a mile away-- and you know

that this is a person of faith.

For me, it is empowering.

I used to be very,

very meek
and very, very quiet.

And not anymore.

PRODUCER:
What shifted?

I got divorced.

[laughs]

And then, I became a b*tch,
I don't...

I don't know.
I got older, I experienced

some ugly [bleep]

and then I was like,
you know what?

I'm not gonna be
like that anymore.

Like, they respect when you say,

"No, this is what I'm doing,"

more so than, like,
"If you want me to."

ANTHONY:
Now I love the idea

of this covered streetwear vibe.

So I think all around,
a strong maybe.

PRODUCER:
How do you think it went?

[laughs]
I'm not sure how it went.

PRODUCER: So I just wanted
to let you know

that you have been
cast on the show.

Are you kidding me?

[laughs]

Are you serious?

PRODUCER:
Yes.

Oh, my gosh, my heart.

PRODUCER: Do you think
you could win Project Runway?

I think I can win.

I inhale sewing.

That's, like, my breakfast.

Bye!

My name is Margarita Alvarez.

I am 30 years old,
from San Juan, Puerto Rico.

Growing up in Puerto Rico
was amazing.

I mean, you're on a beautiful
island. It's lush.

MALE PRODUCER: It sounds like
you maybe begrudgingly made

the move to the United States.

Yeah.

I saw what was happening
with Puerto Rico,

and it's really bad.

Like, the economy's terrible.

I had a design company

back in Puerto Rico
that I had to close down.

And my parents were like,
"Get out."

[sniffles]

They were like, "If you want
to be successful in your field,

you have to leave."

And I was like, "You're right."

Moved to L.A., 'cause
it's beautiful and gorgeous

and sunny.

PRODUCER:
Margarita Alvarez.

-How are you?
-Good, thank you. -We're good.

ANTHONY: Welcome, welcome.
All right, well,

take us through a few things.

This is kind of inspired
on the...

Dior new look.
It's like my take on it.

So this actually inspired

this whole little
preview collection.

So, this is my favorite piece.

This little asymmetrical
corset crop top.

It's so cute.

[sing-songy]:
It is reversible.

ANTHONY:
I was about to say, girl,

you got a lot of energy.
I'm like,

"All right. There's my coffee.

-[laughter]
-There's my coffee."

Hey, guys. Come on in.

If I sketch over here,
then, okay, I'm ready to sew.

It's a tiny space,
but I make it work.

And if I have to cut fabric,
then I'll go back outside.

This will be the situation.

This will be it. Right here.
Hands and knees.

So this is kind of like
my cutting table.

If I do this here,
Steve will totally

dance around my stuff.

[dog barks, then growls]

And then I have to do this
before the dog

and the roommate get here.
Kind of...

It's a workout.

I really usually don't do this

looking all pretty.

-And here we go.
-[dings]

Bun. That's the way to do it.

And then I also did this, like,
hand-embroidered lace,

and then, like, a nice cropped,
white long pant

that goes with that.
So my aesthetic is very Latin.

I love glitter.
I mean, let's be honest.

Anything sparkly,
I'm like a moth to a flame.

It's probably the Cuban in me.

I love your choices of print.

It's very lady-like and elegant.

I would like to see you

doing silhouettes that
we haven't seen before.

I worry about this going
a little matronly.

-Yes. -Yes. -It's that Tim Gunn
"M" word. [laughs]

This is solely based on
the fact that

I have $20 in my bank account.

-Right.
-I used

-what was left of this.
-Mm-hmm.

Had this and made it work.

[voice breaking]:
Like...

Why are you-- what's wrong?

What's-- speak.

I just want this so bad.

If we decide to
move you forward,

someone will be in contact.

♪ ♪

PRODUCER:
You've been cast on season 16.

[inhales]
Really? [laughs]

MALE PRODUCER: What are you
gonna bring to the show?

Puerto Rico. P.R. to P.R.

I don't know.
I'm gonna bring some "flava."

Up next, designers who refused
to take "no" for an answer.

KENYA: You can't forget
about me. I'm short,

I'm fat, I'm bald,
I have glasses.

-You can't forget me.
-And later,

double trouble.

What's the hardest thing
either of you,

separately,
have ever had to go through?

-When Claire had a boyfriend...
-I was gonna say boyfriend.

-I was gonna ask you that.
-Oh, my God!

-♪ ♪
-Welcome back.

This is the Road to the Runway,

the Project Runway season 16
casting special.

I heard a quote recently.

It said, "There's no telling how
many miles you will have to run

while chasing a dream."

Well, I'm willing to bet that
our next group of designers

has what it takes
to go the distance.

My name is Samantha Crossland.

I am 36 years old

and I'm from Minneapolis.

This is probably my sixth time
applying, seventh.

I'm not sure at this point.

It's been a lot of times,
so hopefully

you'll remember

how adorable I am

and give me a call back.

[phone ringing]

♪ ♪

Samantha,
tell us about yourself.

My label is Samantha Rei.

I've been designing
for about 17 years.

This collection was actually

the first time I ever told

my own story instead of
somebody else's.

It was the first time
I just kind of,

like, laid myself bare.

And each garment is inspired by

a feeling or emotion.

So this was social anxiety.

That feeling you get
in your chest

when you feel like
everyone's looking at you.

This is the, kind of,
feeling of...

of dread. And then this was

the person on your shoulder
kind of telling you

that you're making a mistake.

And then this one was hope.

Like, in the darkness, your
heart is gonna just burst forth

and you're gonna make
the right decision.

CATALINA:
This series, I think,

is really beautiful in,
like, a poetic way.

♪ ♪

Hey, you want to see my closet?

It's my sanctuary.

My friend says my style is
decorative clutter.

I have a purse
that's a telephone.

[phone ringing]

It actually works.

MALE PRODUCER:
Describe your design aesthetic.

Kate Spade meets
Vivienne Westwood

My stuff is very structured.

I love texture, layering.

I try to think of ways
of accentuating

the body without making it

about sex.

Do you pay some attention
to plus-size design?

I spent my whole 20s
being bigger

and being frustrated
that nothing fit me.

I wanted to be cute
and fashionable.

I don't want to have someone
tell me that

they would love to wear XYZ

but they're too old,

or they're too big,

or too thin, or too short.

They shouldn't have
to apologize for

the body they have.

CAROLE: The pieces in the front,
I think,

are just really

ethereal, absolutely wearable.

-Based on those, it's a yes
from me. -Thank you.

Like, I feel like you're
my friend.

-[laughter]
-I do.

For me,
it's gonna be a yes, too.

I'm a fun, cartoon person.

I have cartoon hair

'cause I wanted to be a cartoon.

I try to live my life
as magically as possible.

[giggles]

DEYONTÉ:
Hey, Project Runway.

This is Deyonté Weather.

I'm 36 years old

and I'm from Chicago, Illinois.

You know, I'm the first
to graduate from high school,

I'm the first to graduate
from college.

I moved to Seattle at 19.

I was fed up with
the environment in Chicago,

I was fed up with the violence.

I was fed up, and I knew that,
if I didn't leave,

I would probably
either be k*lled

or something would happen to me.

And not many people
from where I come from

can say they've done something
like this.

Deyonté Weather.

-Hello.
-Hello. -Hi.

-Hey.
-I'm excited to be here.

I love architecture.

I kind of was inspired by
the cityscape of Chicago

with this collection.

It's white denim underneath.

And then,
it's another mesh fabric

that I built on top of it

to create the illusion
of the building

and the cityscape.

PRODUCER: What's it like being
a straight man in fashion?

What's the problem
with a straight man

being in this industry?
Why can't I do that?

I think I got what it takes,
no matter

my sexual orientation.

Everybody can't be a rapper.

Everybody can't be
a football player.

What about guys that design?

You know? I want to be that
inspiration to young men

that there's other things
out there that we can do

and succeed in it.

I do love pops of color,

so I bought a bow-print gown.

-Can you pull it out? I'm just
curious.... -Yeah, absolutely.

So I just wanted
to show you guys

that I'm very versatile.

I'm here to work hard.

Can we see the other gown
that you have?

Yes, absolutely.

So it's like a peplum

and some horse hair in there.

I call this the "Black Raven."

Oh, that's nice. You've done
the best job with faux fur

-of the lot. Of anybody.
-Thank you. I appreciate that.

-And it looks expensive.
-Yeah.

I've really been working hard.
I'm dedicated,

I'm determined, I'm driven.

And how are your skills
under pressure, time-wise?

Everything I do
is under pressure.

They say diamonds are made
under pressure,

so you're looking at one.

I work full-time.
I come home and sew every night.

I'm about to be a dad,

so I'm super excited.

-JUDGES: Congratulations.
-Yeah.

MILA: I think you have a lot of
potential. I get...

-where you're coming from with
this collection. -Thank you.

We'll definitely give you a call
by the end of the day.

Okay. Thank you, guys.
Take care. Have a great day.

See, like, I can do this.

This is what I do.

[laughter]

My name is Kenya Freeman.
I'm 37 years old

and I am a resident
of Atlanta, Georgia.

♪ ♪

-I keep it light.
-All right. Showtime.

-Hello, hello.
-Hey.

-Hey.
-MONDO: Tell us about yourself.

I am a women's
ready-to-wear designer.

Who's your woman?

My woman, her name is Toni.

Toni is a working professional.

So what's your favorite piece
up here?

My favorite piece is this top.

She can pair it with

her favorite skirt
to go with this.

Let's talk about the jumpsuit.

I play around with knits
a little bit only because

I don't like them; I can't
manipulate them as much as

I can wovens.

I put, like,
a little bit of boning

in the top to hold her up.

I bet Toni would look good
in that.

Oh, Toni would look cute.
And then, like,

on the butt part...

MONDO: [laughs]
"The butt part."

[laughter]

KENYA:
I love all things peplum,

so I think I create them

in every color and every shade.

And they're comfortable.

And they hide your stomach.
[laughs]

You can't forget about me.

I'm short, I'm fat, I'm bald,

I have glasses.
You can't forget me.

I love the wrap dress.

I'm not Diane, but, um...

[laughter]

I'm not the master of the wrap,

but I do like
transitional things

and things that don't have
expiration dates, you know.

I like to stay relevant
and with the trends,

but I don't really care
for fast fashion too much.

-ANTHONY: So you've never
tried out before. -No.

-So why now? -KENYA: I just
feel like it's my time.

I think I have something
that the world

needs to see.

It's-it's been a long road.

It's been really, really long.

Like, stable residence?
Absolutely not.

I'm a total gypsy.

Like, sleeping in my car.

I've been evicted three times.
My credit sucks.

I don't even think I could get
air on my credit.

It's just been
really, really bad.

I'm too big for amateur night
at the strip club,

-so I can't get extra
to do that. -[laughter]

-I don't work well on a pole.
-[laughter]

I just want to make
wonderful clothes.

I like ladies to look like
ladies and look beautiful.

I don't fear anything

because I know what

the bottom looks like.

Why not take a risk

and then something great
to come out of it, you know?

I have to keep pushing.

[laughs]

Kenya, I-I love you.
And I know your struggles.

-I think your clothing is
really, really good. -Thank you.

This is what she's doing
in real life, on a budget.

-ANTHONY: Right. -What will
you do when you enter Mood?

-MONDO: When you're given,
like... -[laughter]

The world is
at your fingertips.

-MONDO: When you're given
that budget. -Okay, honey,

-you give me a budget...
-[laughter]

It's okay. Smile.

It's good. Come give us a hug.

Come here.

Good job, baby girl.

-Thank you. -ANTHONY: Now she
got me tearing up.

-[laughter]
-Good luck, girl. -Thank you.

PRODUCER:
You have been cast

on season 16 of Project Runway.

[laughs]

PRODUCER:
Congratulations.

We're so happy for you.

[sighs]

Coming up, double trouble.

I'm not a smoker,
but I feel like I need

a smoke.

[both vocalize]

And later...

Both of these are, like,
halter back dress shirts

'cause, I mean, guys have, like,

pecs, too. I don't know.
It's weird.

Welcome back.

This is the Road to the Runway,

the Project Runway season 16
casting special.

Our next two designers share
a birthday; they live together

and even finish
each other's sentences.

Luckily, their designs
speak for themselves.

Hey, everybody,
I'm Shawn Buitendorp.

And I'm Claire Buitendorp.

And yes, you're seeing double.

SHAWN:
We are twins.

CLAIRE:
We design collaboratively

with our brand Shock and Awww.

Being twins,
people like to say,

Claire, you're so effeminate.

I like being a little sex pot.

Oh, Shawn, you're the edgy one.

If we want to have a twin
moment, these lead to both

the shock and the awe.

-They're bright,
they're colorful. -Colorful.

SHAWN:
The epitome of us as twins.

Similar, yet different.

PRODUCER: How would you describe
your aesthetic?

My girl is bold.

Eclectic. Confident.

We definitely hold
to a very rock-and-roll style.

Shawn Buitendorp.

My real strength
lies in leather.

All cut-out,
metallized leather,

handsewn both front and back
on deerskin.

So, this one has
the cobra design,

again, all hand-cut, hand-pieced
with the contrast sleeves.

So, clearly, this is
not your first rodeo.

This is not.

Hello.

-Hi. -Hi.
-I'm the other half.

So, Claire, let's look
at some of your pieces.

Yeah. Like, this dress is...

it has both a sporty

and a sweet element to it.

It has, you know, the nipped-in
waist, the full skirt.

And I also have
a metal mesh dress.

My personal aesthetic

is to create

classic silhouettes
embellished to a level

that they have now become
statement pieces.

PRODUCER: Were you born, like,
minutes after each other

-or was it a cesarean?
-Oh. Not even. -Not even.

SHAWN: We were actually,
we were transverse,

-so we were side to side.
-PRODUCER: Okay.

Claire was on top.
I was on the bottom,

with hiccups, because I was
running out of amniotic fluid

-and my...
-It passed through me to her.

SHAWN: And then my mom
said Claire would...

-k-k-k-k-kick...
-In the head.

...to stop the hiccups.

-So... -You got to do
what you have to do.

SHAWN: There was no way we were
gonna be birthed naturally.

Cesarean.



This jacket here is a lambskin
motorcycle jacket

studded with Swarovski
star studs

and then put this cheeky phrase
on the back,

"Seduce and Destroy."

Precisely what we will be doing

with the competition
at Project Runway.

No, we will not k*ll them.

There will be no scissor
shanking, I swear.

[both vocalize]

Welcome back.

-Why, thank you.
-Now we're together.

What's the hardest thing
either of you, separately,

have ever had to go through?

Um...

Doesn't have to be
fashion related.

-No, no. -Oh, it's not.
It's not. -CAROLINA: Okay.

-When Claire had a boyfriend.
-I would say boyfriends.

-I was gonna ask you that.
-Oh, my God.

-I was gonna ask you about
relationships. -[laughter]

My first boyfriend,
I think I was 17

and then Claire had one


Of course they're
never good enough.

-I'm like, "Shawn, come on."
-Well, it was like...

I wanted to experience
what that was like

and I don't like you

nearly as much as I like her,
I'm sorry.

-But how did the boyfriends
deal with it? -Yeah.

Oh. I think they got
more of what they wanted

-than we've got what we...
-[laughter]

-Well...
-Oh, well, also the time...

My boyfriend, his mother
thought our relationship...

BOTH:
...was incestuous.

-Oh.
-[laughs]

BOTH:
Yeah.

Thank you for coming in.

-Thank you for having us.
-Good luck.

I hope to see one
or both of you.

-As do we.
-[whispering]: You want us.

-SHAWN: Have a lovely afternoon.
-All right.

CAROLINA:
Thank you, you too.

CLAIRE:
Great to meet you guys.

I'm not a smoker,

but I feel like I need a smoke.

Like, that's a lot.

All year round.

Right now we're gonna go
dream up some amazing ideas.

And we'll see you on the runway.

Up next, an outfit that
offers so much more

than just comfort and style.

AARON: There's a hidden pocket
right here

so you can feel yourself.

And later...

This is a shirt
that I designed myself.

In the USA, you can eat
a lot of butter.

I gained so many weight
when I came here.

Welcome back.

This is the Road to the Runway,
season 16.

"Gender-fluid"
is more than a buzzword.

It takes androgyny
to a whole new level.

Our next group of designers

challenge us
to take another look

at what we consider to be
traditionally masculine

and feminine.

Hi, guys. My name's Aaron.

That side of the street is
Brooklyn, but we're in Queens.

Let's go see my apartment.

♪ ♪

Hey, guys.
Welcome to the closet tour.

I love, like,
a simple silhouette,

especially
if I'm wearing a dress.

I like to wear things
that are feminine

but also playing
with masculinity.

That's kind of
how I design, too.

Aaron Myers.

My concept for this
whole collection is the idea

of what traditional menswear
meant versus, like,

what it can be.

Basically,
this is kind of, like,

a cute little schoolboy version
of, like, what it means

to, like, kind of grow up.

And I tried to do
some funny things, like,

there's a hidden pocket
right here,

-so you can feel yourself...
-[needle scratches LP]

...but not feel yourself,
hide some things.

I don't know, dudes,
like, hold themselves

all the time, so it's kind of,
like, playing with that, so...

-Yeah, exactly. Like...
-[phone rings]

And then I just had this,
like, extended fly front

that kind of, like, looks
like a p*nis, but not a p*nis.

And this one's, like, super...
actually really long,

um, and kind of drags
to the floor sometimes,

playing with the idea that,
like, "size matters."

Both of these are, like,
halter back dress shirts,

which is, like, kind of cool.

Darts, which is, like,
traditionally feminine, but I,

like, wanted to have
a male dart, 'cause, I mean,

guys have, like...
like, pecs, too.

I don't know. It's weird.

Born in Jackson,

grew up in West Tennessee,

and we are, like,
a town of, like, 2,000.

I got made fun of-- like,

people used to call me a girl.

And I was always
a Goody Two-shoes.

I don't date, so, like...

I'm kind of a prude.

Like, I'm still a virgin.

Like, for me,
sketching is kind of...

like, comes out of a necessity

in having
to figure something out.

What is a masculine,

like, female,
and a feminine boy?

And just, like,
trying to, like, see that

from all sides
and not exploit it.

I did some, like,
really cool knitwear recently.

This one specifically is, like,

Hari Nef,
the transgender model.

I'm so happy that
you're doing knits like that.

And then I have
these really funny,

like, Dada denim

that you don't really,
like, know how they wear,

how they function.

I love everything.

-Cool. -I think you're thinking
outside of the box.

I wish you put

a little bit more thought
in your fabrications.

But I think for me it's a yes.

PRODUCER:
...could win Project Runway?

AARON:
Why else do you do something

if you're not gonna, like,
do your best and-and win it?

I'm Brandon Kee.

I grew up in Murray, Utah.
I live in San Francisco,

California,
and I'm 24 years old.

I brought these three pieces
because I feel like

this kind of represents me.

I almost came out wearing it,

but I felt like that
would be a little weird.

That wouldn't have been weird.

ANTHONY:
Now, did you make

these textiles?

Yeah, it was like

an all green, purple textile,

and it was, like, very yellow,
and then I dyed it.

The reverse side is
cotton jacquard.

Can you bring this
middle one to us?

BRANDON: It was in, like,
the home furnishings...

-It's nice and soft.
-Yeah.

It was beautifully soft,
and, like, everyone told me

from the get-go, "No, Brandon,
you can't use this,"

and I was like,
I'm gonna make it work.

PRODUCER:
How would you

describe your aesthetic?

It's really me.

I'm kind of the brand--

the poster boy.

I've always been, like,
huge into hip-hop,

and so I really like, kind of,
the oversize, baggy,

kind of like punk attitude--

that... that vibe
that comes with it.

What really makes it for me

is the fabric and manipulation.

Can you just show us that
a little closer?

ALLISON:
Yeah, can I see that up close?

MILA:
That looks amazing, wow.

-ANTHONY: Now, timing-wise...
-MILA: Yeah.

...what are we looking at here?
[laughs]

I-I probably spent maybe,
like, 12 hours.

Okay.

This is my girlfriend,
Dina Marie.

-What do we got here?
-Some tea.

-Some tea?
-Yeah.

PRODUCER:
How did you get into fashion?

BRANDON: I don't know,
it just more sort of

got into me--
like, that's how I was...

could, like, speak,
'cause I was always

really quiet in school,

and I was really shy.

For me, I'm just gonna say

-I would love to see you
on the show. -I would, too.

MILA: I would love
to see more from you.

ALLISON:
Me, too. One, two, three.

One, two, three.

Boom, boom, boom.

MILA: You have such
a fresh point of view

and thoughtfulness to your work.

-The textile, the trimmings,
-ANTHONY: Yeah.

and then the construction
is great, so...

It's probably the easiest yes
we've given all day.

-Yeah.
-That a happy? You happy?

I'm humbled, for sure.

-Very cool.
-He's laughing on the inside.

♪ ♪

Hey, guys,
welcome to Oakland.

My name is Michael.

Our last one of the day.

Let's end on a good note.

-Hopefully. -[laughter]
-Pressure, pressure.

Basically, I focus a lot
on making really cool,

normal pieces with, like,
fetish undertones.

So that's where all
of my rings--

it's kind of inspired by, like,

obviously, the g*y scene
in San Francisco.

Then, like, it goes into

fetish pieces,

like tying everything up.

And it's a multi-style piece

focusing on undressing,

and the sleeves are open.

You can tie the cuffs,
if you'd like,

or tie the ties
around the waist.

And then it kind of creates
like a kimono look to it.

I like to pair it
with this skirt, which is also,

like, kind of a fetish piece,
you know, it's got, like,

San Francisco [bleep] rings
everywhere, so...

[laughter]

MICHAEL:
My whole aesthetic,

it is about normalizing

sexuality, and normalizing

gender identity,

and doing it in a way

that isn't gonna, like,

slap people in the face

and make them scared of it.

MALE PRODUCER: So, like,
are you dating anybody?

No, I... kind of, like,

don't believe in relationships,
like, for myself.

I'm kind of more sexual.

I'm kind of like a sl*t.

If you're a wh*re, like,
own up to it.

Just don't feel ashamed of it.

Going into my menswear,

I do like to play with a lot

of feminine undertones,

like the p*ssy bow.

A short that unzips
only on the sides.

So you could just, like...

-you could wear it.
-ANTHONY: See?

My favorite piece is this.

-The blouse with the ties.
-ALLISON: Mm-hmm.

Because that feels luxurious
to me.

ALLISON:
And I like how

you haven't made it so obvious--

[bleep] rings and p*ssy bows
and stuff.

-I'm like, "Okay."
-Right.

-But if you never said
any of that... -Right.

...I'd be like, "Oh, that's
a really beautiful shirt."

-Yeah. -Mm-hmm.
-"Oh, that's a cute ring."

And really subtle.

So in seeing the potential
and your point of view,

I have to give you a yes.
I like what you're doing.

-All right. Bye, y'all.
-Bye. -Thank you. -Bye.

ANTHONY:
For someone so timid,

you have to wonder
what's going through his mind.

Yeah, he's got
a whole other agenda.

ANTHONY: Like, "Girl,
what's your bedroom look like?"



♪ ♪

I'm Sentell, I'm 33,
from New York, New York.

-[laughs]
-Sentell McDonald.

SENTELL:
I spent most of my life

as a professional dancer.

As I got older,
I realized it's something

that you definitely
cannot age into gracefully.

Design is like my second lease
on life.

-Thought you would be shirtless
from this photo. -[laughs]

-Take us through your most
favorite. -I design menswear.

This is a jumpsuit that was
inspired by global warming.

And this one is just
a fun little take

on a little dress that I love.

It's kind of weird and cute
at the same time.

I grew up on a farm
in North Florida.

So you have two towns.
You have, uh, Brooksville,

which is where
all the blacks live.

Spring Hill was where
the whites lived, and

I didn't really fit in much

because I was
the only black kid in my school

in Spring Hill, and then,
when I would go to Brooksville

and hang out with all the
black people, they would say,

"Oh, why do you talk so proper?"

You know.
"You're trying to be white."

So I got it from both ends,
you know, and that's why,

when I turned 17 and graduated,

I left, and I never went back.

I do have a sense of

always feeling
kind of unwelcomed. Always.

That's why I feel like,
if you go into my apartment,

positive affirmations are
everywhere, so, just anything

that, uh, kind of like pushes me

to go a little bit harder
in life.

My biggest fear is dying without

showing what it is
that I have to offer.

This pant is, like,
really awesome.

It's two layers--
a crepe and a chiffon.

You can flip this over,
tie it at the top, and it's like

a faux jumpsuit kind of thing.

I got a little special guest
for you.

Her name's Frida.
What's going on, Frida?

-[whining]
-Hi, Project Runway!

-[yipping]
-Okay.

I like the ease
of where you're going.

I don't like the finishes
or the...

A lot of the seaming is not...

precision, so for me,
it's a strong maybe.

Cool. Thank you.

-Hi, Sentell.
-How are you?

-How are you?
-Nice to meet you.

Congratulations.
You've been chosen

-to be on Project Runway!
-Oh, my God!

That's amazing.
That's so crazy!

Up next-- you'll never think
of butter the same way again.

This is a shirt
that I designed myself.

In the USA,
you could eat a lot of butter.

And later, 16 designers
in less than three minutes--

your final recap before Project
Runway season 16 begins!

Welcome back.
Project Runway offers

our next group of designers
something

they cannot get
anywhere else in the world--

a platform to express
their unique points of view.

They remind us
that fashion is more

than a shirt or a pair of pants.

It's a reflection of who you are
and from where you come.

Hi. This is Kento Kameyama.

I'm 38 years old.

Hi.
I live in L.A.

Don't tell people I'm 38.

... my hand into it,
or do you want me

to just, like, do it YOLO?

All right, Kentaro,
tell us about yourself.

KENTARO: I'm from Japan,
and I came to America

to study classical piano,
but then,

I got tendinitis,
so I was like, "Fashion."

So, kind of decided
to do fashion.

ANTHONY: What is
your design aesthetic like?

-Who's your girl?
-Usually

I get inspired by music,

so, like, many of stuff here...

It's very beautiful,
but it's sad.

If you don't take sad things,
turn into something beautiful,

our life is gonna be so sad

-and miserable.
-Beautiful. -Yeah.

-Do the snow angel like this.
-Mm-hmm.

So that's a snow angel dress.

She was one
of my best friends.

-Stunning. Oh, my God. -Mm-hmm.
-That's a beautiful tribute.

[piano plays classical music]

This piano is out of tune.

Playing piano, for me,
is very healthy mentally.

Kind of keeps me sane.

MILA: What interests you
about Project Runway?

Why did you decide to audition?

-Well, it's famous.
-[laughter]

-Yeah. -Yeah. -Yeah. Please show
us the rest of your work.

MILA: But I could see it
walking the runway

-with the veil down.
-Right. With the veil.

MILA:
It's incredible.

Can we see the print?

I studied Chinese calligraphy.

I went to 99 Cents Store,

and I got a cheap white thing,
like,

and I just paint it this way.

PRODUCER:
What is your secret weapon?

My secret weapon is gonna be,
I can be a fit model.

I'm five-nine, 120 pounds--
very much model size.

So instead of getting a fit
model when I can fit myself,

and if it works, it works.

-I'm obsessed with you. I want
you on the show. -It's a yes.

-It's a yes. Big yes. -It's a
unanimous yes. -A big, fat yes.

I can't wait to, to,

uh, see your clothes
one day in the stores.

-Me, too.
-[laughter]

-He is so adorable.
-So adorable. -Yeah.

-And so talented.
-MILA: I want to be his friend.

I will see you
on the Project Runway season 16.

Bye!

♪ ♪

-How are you? -Good! -Kudzanai,
tell us about yourself.

My name is Kudzanai.
Uh, originally born in Zimbabwe.

I like androgyny,
so I like my pieces

to also make sense on men
and women.

I love color. I love textures.

I've been designing
for the last 12 years.

Talk to us
about your favorite piece.

My favorite piece
would have to be this one,

just because it reminds me
of Africa.

It reminds me of the culture.

It's also very fashion-forward,
being oversized,

and, you know, it's a easy wear.

But it's still very regal
and it demands some attention.

-Let's get down to business.
-All right.

Where is Cheese at?

-Cheese! You love Cheese, right?
-[laughter]

Everybody loves Cheese.
Cheese is at home

-sitting on the couch.
-ADRIENNE: Oh, my God.

KUDZANAI:
Cheese is a phenomenal dog.

Everybody gets scared
when they see him,

'cause he just looks

like he's gonna do damage.

But he's the happiest dog ever.

Take us to the men's look.

KUDZANAI: I love tapered bottoms
but baggy up top

so it kind of bunches
a little bit.

And I love mesh.
The idea behind it

was to mesh it with the message

behind my clothing,
which is kind of, like,

thanking God. And hence why

I put "thank God"
on the back of this jacket.

This is my work studio.

And, of course, my Brother
Project Runway sewing machine.

My best friend.
Besides my sister.

Don't let her hear me say that.

This piece, it's got
the super big pocket.

Very, very light,

soft cotton. The top is
kind of like a crop top,

but then it has the cape.

-And this one? -On a guy, it's
one of those oversized shirts.

On a girl, wear it as a dress.

-And everything is functional.
-PRODUCER: Could you win?

-That's my goal. -PRODUCER: What
would it mean for you?

KUDZANAI: My grandmother,
she's the reason

why I started most of this--

for her to see that and just...

have joy.

For my mom to be excited.
I want to make my dad

really proud. I've had
a hard time making my dad proud

my-my whole life.

Kudzanai, I love you.

You're so aware of yourself

as a designer and artist.

There is a story
behind every piece.

-It's definitely a yes for me.
-I love how you've

styled everything.

-Thank you so much.
-Congratulations.

-Thank you.
-Yeah.

Later!

♪ ♪

Hi, everybody. I'm Vincent Yu.

I'm also known as ChaCha.

I was raised
and born in Taiwan.

You're gonna see three panelists
sitting at the table.

Um, when you walk in there,
you want to stand on the "T."

Vincent,
start with your favorite piece

that you brought us.

I went to a thrift shop,

and I found this Tweety Bear...

Not "Bear." Tweety...

-Chicken? Bird.
-Bird. -Bird.

-[laughter] -"Tweety Chicken."
-"Tweety Chicken."

CHACHA:
I love stuffed animals.

-And butter.
-Mm-hmm. Yeah. Yeah. -Yes!

This is a shirt
that I designed myself.

In the USA,
you can eat a lot of butter.

I gained so many weight
when I came here.

And I love burgers and
I love fries. And free refills!

I mean, free refills, people!

When I wear on this jacket,
I feel like I'm Anna Wintour.

I'm the king of fashion.

♪ ♪

Show us two more from your rack.

-[gasps]
-Choose carefully.

This is a coat.

I went to a little fabric shop,

and I found this.

Care Bears.
I love Care Bears so much.

-I have one more, right?
So, this one is a top. -Uh-huh.

I have this scream girl here.

Mm-hmm.

Yeah, Psycho.

She is super famous.

PRODUCER: Talk to me about being
in the room with the panelists.

CHACHA: They really liked all
of my garments.

Then the other judge,
she told me...

What if you came on the show and
someone said you can only buy

-black fabric?
-[gasps]

I don't like the color black.

Not because I'm r*cist.

But I just don't go with black.

But I wear black pants
'cause my legs are thick.

-I want to look slender.
-Yay!

I think it's really fun.
I think it's really out there.

I-I like it. I don't...

-I can't explain why. -Clothes
like this, it's super wacky.

I can see that there's, like,
some attention to the way

-it would fit a woman's body.
-MONDO: I think that you have

a really, really special
relationship with your clothes.

Even though it's, like, crazy,
crazy, crazy across the board,

there is cohesiveness.
For me, it's a definite yes.

Thank you.

So you guys
have really worn me out.

So right now is the time for me
to take a nap.

And then we'll see you guys
on the runway!

Up next, 16 designers
in less than three minutes.

Your final recap before Project
Runway season 16 begins.

Welcome back to the Project
Runway casting special.

Season 16 is about to begin.

But first, here's a brief recap
of each designer

to help you hedge your bets.

Who will be in? Who will be out?

And which one
of these talented individuals

will win Project Runway
season 16?

♪ ♪

My thoughts and my designs

come while I'm sleeping.
That's why I keep two computers

and three notebooks next to me
at all times.

And I'll roll over
and I'll wake up and I'm like,

"Oh, my God,
that'll be so cute."

I think my style are

really unique.

Flirty, sparkling, pop!

It's wacky, but it's wacky

in a good way.

I like design challenges.

I love to play with shape
and silhouette.

My versatility, my skills,
my design eye--

it's my package.
[laughs]

I never had to question
who I was.

My personal style
is kind of funky, kind of edgy.

I'm really into African prints.
I like to be bold

and expressive
in everything that I do.

I have wings, so I'm gonna fly.

And I'm not ever gonna fall.

My whole aesthetic, it is

about normalizing sexuality and
normalizing gender identity.

I am very polite,

but I'm gonna get what I want.

In my clothes,
I think I just take on

to the whole African culture--
South African,

Ethiopian, Nigerian,
everything.

If my goal wasn't to win,

I wouldn't be sitting here.

I am competitive in all aspects
of my life.

And I don't want to say
that I don't want

other people to do well,
but I generally want

to do better.

I wanted to do something
more crazy

with, like, what gender meant
and, like, what is

a masculine female
and a feminine boy

and trying to see that
from all sides

and not exploit it.

I'm a fun, cartoon person.

I'm kind of an escapist,
and I'm a whimsical realist.

I try to live my life
as magically as possible.

[laughs]

People think, like,
fashion is pretentious.

But it's really, you know,
between you and the jeans.

I'm very careful
with proportion. I want to make

a person look good,

no matter what I do.

I'm ready.
Like, I've been sewing

since I was six. My design
aesthetic would be modest,

putting, like,
a more modern take on things.

If I don't believe
in my vision,

then who will believe
in my vision?

I want to come
and win this show.

I'm determined, I'm driven.

I'm usually a leader.
I've always been a leader,

all my life.

I like to excel
in all areas of life.

I innately know
I am supposed to be someone.

I'm destined for greatness.

I've always been,
like, huge into hip-hop.

Kind of the oversized, baggy.
Kind of, like, that vibe

comes with it.
It's got to be, like, edgy,

and it's got to, like,
have this, like, attitude,

or swagger to it.

It's really me.

I think design is

not about fashion.
Design is problem solving.

The goal of mine, as
a designer, is to make things

that are, like,
useable, functional,

and can transcend time.

I've kind of, like, got it all.

I do menswear.

But in the same way
my menswear is kind of unisex.

The main purpose of life is to,
like, squeeze the juice

out of it, you know? My biggest
fear is dying without showing

what it is that I have to offer.

Thanks for joining me.

And happy sweet 16,
Project Runway.

Season 16 starts now!

HEIDI: Visit myLifetime.com
to learn more

about the fashion you've seen
on tonight's show.